@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
-# (c) YashDK [yash-dk@github]
+
 
 from ..consts.ExecVarsSample import ExecVars
-from ..core.database_handle import tkdb
+#from ..core.database_handle import tkdb
 from tgtk import SessionVars
 import os
 
