@@ -37,7 +37,7 @@ async def progress(current,total,message,file_name,start,time_out,cancel_msg=Non
             ''.join([get_val("REMAINING_STR") for i in range(10 - math.floor(percentage / 10))]),
             round(percentage, 2))
         
-        tmp = progress + "{0} of {1}\nSpeed: {2}/s\nETA: {3}\n".format(
+        tmp = progress + "{0} of {1}\nSpeed: {2}/s\nETA: {3}\nusing engine: telethon".format(
             human_readable_bytes(current),
             human_readable_bytes(total),
             human_readable_bytes(speed),
@@ -47,14 +47,14 @@ async def progress(current,total,message,file_name,start,time_out,cancel_msg=Non
         try:
             if not message.photo:
                 await message.edit(
-                    text="{}\n {}".format(
+                    text="**Uploading:** `{}`\n{}".format(
                         file_name,
                         tmp
                     )
                 )
             else:
                 await message.edit(
-                    caption="{}\n {}".format(
+                    caption="**Uploading:** `{}`\n{}".format(
                         file_name,
                         tmp
                     )
